import * as T from "./types.js";
import * as RPC from "./jsonrpc.js";
type RequestMethod = (method: string, params?: RPC.Params) => Promise<unknown>;
type NotificationMethod = (method: string, params?: RPC.Params) => void;
interface Transport {
    request: RequestMethod;
    notification: NotificationMethod;
}
export declare class RawClient {
    private _transport;
    constructor(_transport: Transport);
    /**
     * Test function.
     */
    sleep(delay: T.F64): Promise<void>;
    /**
     * Checks if an email address is valid.
     */
    checkEmailValidity(email: string): Promise<boolean>;
    /**
     * Returns general system info.
     */
    getSystemInfo(): Promise<Record<string, string>>;
    /**
     * Get the next event.
     */
    getNextEvent(): Promise<T.Event>;
    addAccount(): Promise<T.U32>;
    removeAccount(accountId: T.U32): Promise<null>;
    getAllAccountIds(): Promise<(T.U32)[]>;
    /**
     * Select account id for internally selected state.
     * TODO: Likely this is deprecated as all methods take an account id now.
     */
    selectAccount(id: T.U32): Promise<null>;
    /**
     * Get the selected account id of the internal state..
     * TODO: Likely this is deprecated as all methods take an account id now.
     */
    getSelectedAccountId(): Promise<(T.U32 | null)>;
    /**
     * Get a list of all configured accounts.
     */
    getAllAccounts(): Promise<(T.Account)[]>;
    /**
     * Starts background tasks for all accounts.
     *
     * Acounts with `disable_background_io` are not started, unless the account is the selected one
     */
    startIoForAllAccounts(): Promise<null>;
    /**
     * Stops background tasks for all accounts.
     */
    stopIoForAllAccounts(): Promise<null>;
    /**
     * Performs a background fetch for all accounts in parallel with a timeout.
     *
     * The `AccountsBackgroundFetchDone` event is emitted at the end even in case of timeout.
     * Process all events until you get this one and you can safely return to the background
     * without forgetting to create notifications caused by timing race conditions.
     *
     * Acounts with `disable_background_io` are not fetched
     */
    accountsBackgroundFetch(timeoutInSeconds: T.F64): Promise<null>;
    /**
     * Set disable_background_io for an account, when enabled,
     * io is stopped unless the account is selected and background fetch is also disabled for the account
     *
     * This automatically stops/starts io when account is in the background
     */
    setDisableBackgroundIo(accountId: T.U32, disableBackgroundIo: boolean): Promise<null>;
    /**
     * Starts background tasks for a single account.
     */
    startIo(accountId: T.U32): Promise<null>;
    /**
     * Stops background tasks for a single account.
     */
    stopIo(accountId: T.U32): Promise<null>;
    /**
     * Get top-level info for an account.
     */
    getAccountInfo(accountId: T.U32): Promise<T.Account>;
    /**
     * Get the combined filesize of an account in bytes
     */
    getAccountFileSize(accountId: T.U32): Promise<T.U64>;
    /**
     * Returns provider for the given domain.
     *
     * This function looks up domain in offline database.
     *
     * For compatibility, email address can be passed to this function
     * instead of the domain.
     */
    getProviderInfo(accountId: T.U32, email: string): Promise<(T.ProviderInfo | null)>;
    /**
     * Checks if the context is already configured.
     */
    isConfigured(accountId: T.U32): Promise<boolean>;
    /**
     * Get system info for an account.
     */
    getInfo(accountId: T.U32): Promise<Record<string, string>>;
    draftSelfReport(accountId: T.U32): Promise<T.U32>;
    /**
     * Sets the given configuration key.
     */
    setConfig(accountId: T.U32, key: string, value: (string | null)): Promise<null>;
    /**
     * Updates a batch of configuration values.
     */
    batchSetConfig(accountId: T.U32, config: Record<string, (string | null)>): Promise<null>;
    /**
     * Set configuration values from a QR code. (technically from the URI that is stored in the qrcode)
     * Before this function is called, `checkQr()` should confirm the type of the
     * QR code is `account` or `webrtcInstance`.
     *
     * Internally, the function will call dc_set_config() with the appropriate keys,
     */
    setConfigFromQr(accountId: T.U32, qrContent: string): Promise<null>;
    checkQr(accountId: T.U32, qrContent: string): Promise<T.Qr>;
    /**
     * Returns configuration value for the given key.
     */
    getConfig(accountId: T.U32, key: string): Promise<(string | null)>;
    batchGetConfig(accountId: T.U32, keys: (string)[]): Promise<Record<string, (string | null)>>;
    setStockStrings(strings: Record<T.U32, string>): Promise<null>;
    /**
     * Configures this account with the currently set parameters.
     * Setup the credential config before calling this.
     */
    configure(accountId: T.U32): Promise<null>;
    /**
     * Signal an ongoing process to stop.
     */
    stopOngoingProcess(accountId: T.U32): Promise<null>;
    exportSelfKeys(accountId: T.U32, path: string, passphrase: (string | null)): Promise<null>;
    importSelfKeys(accountId: T.U32, path: string, passphrase: (string | null)): Promise<null>;
    /**
     * Returns the message IDs of all _fresh_ messages of any chat.
     * Typically used for implementing notification summaries
     * or badge counters e.g. on the app icon.
     * The list is already sorted and starts with the most recent fresh message.
     *
     * Messages belonging to muted chats or to the contact requests are not returned;
     * these messages should not be notified
     * and also badge counters should not include these messages.
     *
     * To get the number of fresh messages for a single chat, muted or not,
     * use `get_fresh_msg_cnt()`.
     */
    getFreshMsgs(accountId: T.U32): Promise<(T.U32)[]>;
    /**
     * Get the number of _fresh_ messages in a chat.
     * Typically used to implement a badge with a number in the chatlist.
     *
     * If the specified chat is muted,
     * the UI should show the badge counter "less obtrusive",
     * e.g. using "gray" instead of "red" color.
     */
    getFreshMsgCnt(accountId: T.U32, chatId: T.U32): Promise<T.Usize>;
    /**
     * Gets messages to be processed by the bot and returns their IDs.
     *
     * Only messages with database ID higher than `last_msg_id` config value
     * are returned. After processing the messages, the bot should
     * update `last_msg_id` by calling [`markseen_msgs`]
     * or manually updating the value to avoid getting already
     * processed messages.
     *
     * [`markseen_msgs`]: Self::markseen_msgs
     */
    getNextMsgs(accountId: T.U32): Promise<(T.U32)[]>;
    /**
     * Waits for messages to be processed by the bot and returns their IDs.
     *
     * This function is similar to [`get_next_msgs`],
     * but waits for internal new message notification before returning.
     * New message notification is sent when new message is added to the database,
     * on initialization, when I/O is started and when I/O is stopped.
     * This allows bots to use `wait_next_msgs` in a loop to process
     * old messages after initialization and during the bot runtime.
     * To shutdown the bot, stopping I/O can be used to interrupt
     * pending or next `wait_next_msgs` call.
     *
     * [`get_next_msgs`]: Self::get_next_msgs
     */
    waitNextMsgs(accountId: T.U32): Promise<(T.U32)[]>;
    /**
     * Estimate the number of messages that will be deleted
     * by the set_config()-options `delete_device_after` or `delete_server_after`.
     * This is typically used to show the estimated impact to the user
     * before actually enabling deletion of old messages.
     */
    estimateAutoDeletionCount(accountId: T.U32, fromServer: boolean, seconds: T.I64): Promise<T.Usize>;
    initiateAutocryptKeyTransfer(accountId: T.U32): Promise<string>;
    continueAutocryptKeyTransfer(accountId: T.U32, messageId: T.U32, setupCode: string): Promise<null>;
    getChatlistEntries(accountId: T.U32, listFlags: (T.U32 | null), queryString: (string | null), queryContactId: (T.U32 | null)): Promise<(T.U32)[]>;
    /**
     * Returns chats similar to the given one.
     *
     * Experimental API, subject to change without notice.
     */
    getSimilarChatIds(accountId: T.U32, chatId: T.U32): Promise<(T.U32)[]>;
    getChatlistItemsByEntries(accountId: T.U32, entries: (T.U32)[]): Promise<Record<T.U32, T.ChatListItemFetchResult>>;
    getFullChatById(accountId: T.U32, chatId: T.U32): Promise<T.FullChat>;
    /**
     * get basic info about a chat,
     * use chatlist_get_full_chat_by_id() instead if you need more information
     */
    getBasicChatInfo(accountId: T.U32, chatId: T.U32): Promise<T.BasicChat>;
    acceptChat(accountId: T.U32, chatId: T.U32): Promise<null>;
    blockChat(accountId: T.U32, chatId: T.U32): Promise<null>;
    /**
     * Delete a chat.
     *
     * Messages are deleted from the device and the chat database entry is deleted.
     * After that, the event #DC_EVENT_MSGS_CHANGED is posted.
     *
     * Things that are _not done_ implicitly:
     *
     * - Messages are **not deleted from the server**.
     * - The chat or the contact is **not blocked**, so new messages from the user/the group may appear as a contact request
     *   and the user may create the chat again.
     * - **Groups are not left** - this would
     *   be unexpected as (1) deleting a normal chat also does not prevent new mails
     *   from arriving, (2) leaving a group requires sending a message to
     *   all group members - especially for groups not used for a longer time, this is
     *   really unexpected when deletion results in contacting all members again,
     *   (3) only leaving groups is also a valid usecase.
     *
     * To leave a chat explicitly, use leave_group()
     */
    deleteChat(accountId: T.U32, chatId: T.U32): Promise<null>;
    /**
     * Get encryption info for a chat.
     * Get a multi-line encryption info, containing encryption preferences of all members.
     * Can be used to find out why messages sent to group are not encrypted.
     *
     * returns Multi-line text
     */
    getChatEncryptionInfo(accountId: T.U32, chatId: T.U32): Promise<string>;
    /**
     * Get QR code (text and SVG) that will offer an Setup-Contact or Verified-Group invitation.
     * The QR code is compatible to the OPENPGP4FPR format
     * so that a basic fingerprint comparison also works e.g. with OpenKeychain.
     *
     * The scanning device will pass the scanned content to `checkQr()` then;
     * if `checkQr()` returns `askVerifyContact` or `askVerifyGroup`
     * an out-of-band-verification can be joined using `secure_join()`
     *
     * chat_id: If set to a group-chat-id,
     *     the Verified-Group-Invite protocol is offered in the QR code;
     *     works for protected groups as well as for normal groups.
     *     If not set, the Setup-Contact protocol is offered in the QR code.
     *     See https://securejoin.readthedocs.io/en/latest/new.html
     *     for details about both protocols.
     *
     * return format: `[code, svg]`
     */
    getChatSecurejoinQrCodeSvg(accountId: T.U32, chatId: (T.U32 | null)): Promise<[string, string]>;
    /**
     * Continue a Setup-Contact or Verified-Group-Invite protocol
     * started on another device with `get_chat_securejoin_qr_code_svg()`.
     * This function is typically called when `check_qr()` returns
     * type=AskVerifyContact or type=AskVerifyGroup.
     *
     * The function returns immediately and the handshake runs in background,
     * sending and receiving several messages.
     * During the handshake, info messages are added to the chat,
     * showing progress, success or errors.
     *
     * Subsequent calls of `secure_join()` will abort previous, unfinished handshakes.
     *
     * See https://securejoin.readthedocs.io/en/latest/new.html
     * for details about both protocols.
     *
     * **qr**: The text of the scanned QR code. Typically, the same string as given
     *     to `check_qr()`.
     *
     * **returns**: The chat ID of the joined chat, the UI may redirect to the this chat.
     *         A returned chat ID does not guarantee that the chat is protected or the belonging contact is verified.
     *
     */
    secureJoin(accountId: T.U32, qr: string): Promise<T.U32>;
    leaveGroup(accountId: T.U32, chatId: T.U32): Promise<null>;
    /**
     * Remove a member from a group.
     *
     * If the group is already _promoted_ (any message was sent to the group),
     * all group members are informed by a special status message that is sent automatically by this function.
     *
     * Sends out #DC_EVENT_CHAT_MODIFIED and #DC_EVENT_MSGS_CHANGED if a status message was sent.
     */
    removeContactFromChat(accountId: T.U32, chatId: T.U32, contactId: T.U32): Promise<null>;
    /**
     * Add a member to a group.
     *
     * If the group is already _promoted_ (any message was sent to the group),
     * all group members are informed by a special status message that is sent automatically by this function.
     *
     * If the group has group protection enabled, only verified contacts can be added to the group.
     *
     * Sends out #DC_EVENT_CHAT_MODIFIED and #DC_EVENT_MSGS_CHANGED if a status message was sent.
     */
    addContactToChat(accountId: T.U32, chatId: T.U32, contactId: T.U32): Promise<null>;
    /**
     * Get the contact IDs belonging to a chat.
     *
     * - for normal chats, the function always returns exactly one contact,
     *   DC_CONTACT_ID_SELF is returned only for SELF-chats.
     *
     * - for group chats all members are returned, DC_CONTACT_ID_SELF is returned
     *   explicitly as it may happen that oneself gets removed from a still existing
     *   group
     *
     * - for broadcasts, all recipients are returned, DC_CONTACT_ID_SELF is not included
     *
     * - for mailing lists, the behavior is not documented currently, we will decide on that later.
     *   for now, the UI should not show the list for mailing lists.
     *   (we do not know all members and there is not always a global mailing list address,
     *   so we could return only SELF or the known members; this is not decided yet)
     */
    getChatContacts(accountId: T.U32, chatId: T.U32): Promise<(T.U32)[]>;
    /**
     * Create a new group chat.
     *
     * After creation,
     * the group has one member with the ID DC_CONTACT_ID_SELF
     * and is in _unpromoted_ state.
     * This means, you can add or remove members, change the name,
     * the group image and so on without messages being sent to all group members.
     *
     * This changes as soon as the first message is sent to the group members
     * and the group becomes _promoted_.
     * After that, all changes are synced with all group members
     * by sending status message.
     *
     * To check, if a chat is still unpromoted, you can look at the `is_unpromoted` property of `BasicChat` or `FullChat`.
     * This may be useful if you want to show some help for just created groups.
     *
     * @param protect If set to 1 the function creates group with protection initially enabled.
     *     Only verified members are allowed in these groups
     *     and end-to-end-encryption is always enabled.
     */
    createGroupChat(accountId: T.U32, name: string, protect: boolean): Promise<T.U32>;
    /**
     * Create a new broadcast list.
     *
     * Broadcast lists are similar to groups on the sending device,
     * however, recipients get the messages in a read-only chat
     * and will see who the other members are.
     *
     * For historical reasons, this function does not take a name directly,
     * instead you have to set the name using dc_set_chat_name()
     * after creating the broadcast list.
     */
    createBroadcastList(accountId: T.U32): Promise<T.U32>;
    /**
     * Set group name.
     *
     * If the group is already _promoted_ (any message was sent to the group),
     * all group members are informed by a special status message that is sent automatically by this function.
     *
     * Sends out #DC_EVENT_CHAT_MODIFIED and #DC_EVENT_MSGS_CHANGED if a status message was sent.
     */
    setChatName(accountId: T.U32, chatId: T.U32, newName: string): Promise<null>;
    /**
     * Set group profile image.
     *
     * If the group is already _promoted_ (any message was sent to the group),
     * all group members are informed by a special status message that is sent automatically by this function.
     *
     * Sends out #DC_EVENT_CHAT_MODIFIED and #DC_EVENT_MSGS_CHANGED if a status message was sent.
     *
     * To find out the profile image of a chat, use dc_chat_get_profile_image()
     *
     * @param image_path Full path of the image to use as the group image. The image will immediately be copied to the
     *     `blobdir`; the original image will not be needed anymore.
     *      If you pass null here, the group image is deleted (for promoted groups, all members are informed about
     *      this change anyway).
     */
    setChatProfileImage(accountId: T.U32, chatId: T.U32, imagePath: (string | null)): Promise<null>;
    setChatVisibility(accountId: T.U32, chatId: T.U32, visibility: T.ChatVisibility): Promise<null>;
    setChatEphemeralTimer(accountId: T.U32, chatId: T.U32, timer: T.U32): Promise<null>;
    getChatEphemeralTimer(accountId: T.U32, chatId: T.U32): Promise<T.U32>;
    /**
     * Add a message to the device-chat.
     * Device-messages usually contain update information
     * and some hints that are added during the program runs, multi-device etc.
     * The device-message may be defined by a label;
     * if a message with the same label was added or skipped before,
     * the message is not added again, even if the message was deleted in between.
     * If needed, the device-chat is created before.
     *
     * Sends the `MsgsChanged` event on success.
     *
     * Setting msg to None will prevent the device message with this label from being added in the future.
     */
    addDeviceMessage(accountId: T.U32, label: string, msg: (T.MessageData | null)): Promise<(T.U32 | null)>;
    /**
     *  Mark all messages in a chat as _noticed_.
     *  _Noticed_ messages are no longer _fresh_ and do not count as being unseen
     *  but are still waiting for being marked as "seen" using markseen_msgs()
     *  (IMAP/MDNs is not done for noticed messages).
     *
     *  Calling this function usually results in the event #DC_EVENT_MSGS_NOTICED.
     *  See also markseen_msgs().
     */
    marknoticedChat(accountId: T.U32, chatId: T.U32): Promise<null>;
    getFirstUnreadMessageOfChat(accountId: T.U32, chatId: T.U32): Promise<(T.U32 | null)>;
    /**
     * Set mute duration of a chat.
     *
     * The UI can then call is_chat_muted() when receiving a new message
     * to decide whether it should trigger an notification.
     *
     * Muted chats should not sound or vibrate
     * and should not show a visual notification in the system area.
     * Moreover, muted chats should be excluded from global badge counter
     * (get_fresh_msgs() skips muted chats therefore)
     * and the in-app, per-chat badge counter should use a less obtrusive color.
     *
     * Sends out #DC_EVENT_CHAT_MODIFIED.
     */
    setChatMuteDuration(accountId: T.U32, chatId: T.U32, duration: T.MuteDuration): Promise<null>;
    /**
     * Check whether the chat is currently muted (can be changed by set_chat_mute_duration()).
     *
     * This is available as a standalone function outside of fullchat, because it might be only needed for notification
     */
    isChatMuted(accountId: T.U32, chatId: T.U32): Promise<boolean>;
    /**
     * Mark messages as presented to the user.
     * Typically, UIs call this function on scrolling through the message list,
     * when the messages are presented at least for a little moment.
     * The concrete action depends on the type of the chat and on the users settings
     * (dc_msgs_presented() may be a better name therefore, but well. :)
     *
     * - For normal chats, the IMAP state is updated, MDN is sent
     *   (if set_config()-options `mdns_enabled` is set)
     *   and the internal state is changed to @ref DC_STATE_IN_SEEN to reflect these actions.
     *
     * - For contact requests, no IMAP or MDNs is done
     *   and the internal state is not changed therefore.
     *   See also marknoticed_chat().
     *
     * Moreover, timer is started for incoming ephemeral messages.
     * This also happens for contact requests chats.
     *
     * This function updates `last_msg_id` configuration value
     * to the maximum of the current value and IDs passed to this function.
     * Bots which mark messages as seen can rely on this side effect
     * to avoid updating `last_msg_id` value manually.
     *
     * One #DC_EVENT_MSGS_NOTICED event is emitted per modified chat.
     */
    markseenMsgs(accountId: T.U32, msgIds: (T.U32)[]): Promise<null>;
    getMessageIds(accountId: T.U32, chatId: T.U32, infoOnly: boolean, addDaymarker: boolean): Promise<(T.U32)[]>;
    getMessageListItems(accountId: T.U32, chatId: T.U32, infoOnly: boolean, addDaymarker: boolean): Promise<(T.MessageListItem)[]>;
    getMessage(accountId: T.U32, messageId: T.U32): Promise<T.Message>;
    getMessageHtml(accountId: T.U32, messageId: T.U32): Promise<(string | null)>;
    /**
     * get multiple messages in one call,
     * if loading one message fails the error is stored in the result object in it's place.
     *
     * this is the batch variant of [get_message]
     */
    getMessages(accountId: T.U32, messageIds: (T.U32)[]): Promise<Record<T.U32, T.MessageLoadResult>>;
    /**
     * Fetch info desktop needs for creating a notification for a message
     */
    getMessageNotificationInfo(accountId: T.U32, messageId: T.U32): Promise<T.MessageNotificationInfo>;
    /**
     * Delete messages. The messages are deleted on the current device and
     * on the IMAP server.
     */
    deleteMessages(accountId: T.U32, messageIds: (T.U32)[]): Promise<null>;
    /**
     * Get an informational text for a single message. The text is multiline and may
     * contain e.g. the raw text of the message.
     *
     * The max. text returned is typically longer (about 100000 characters) than the
     * max. text returned by dc_msg_get_text() (about 30000 characters).
     */
    getMessageInfo(accountId: T.U32, messageId: T.U32): Promise<string>;
    /**
     * Returns additional information for single message.
     */
    getMessageInfoObject(accountId: T.U32, messageId: T.U32): Promise<T.MessageInfo>;
    /**
     * Returns contacts that sent read receipts and the time of reading.
     */
    getMessageReadReceipts(accountId: T.U32, messageId: T.U32): Promise<(T.MessageReadReceipt)[]>;
    /**
     * Asks the core to start downloading a message fully.
     * This function is typically called when the user hits the "Download" button
     * that is shown by the UI in case `download_state` is `'Available'` or `'Failure'`
     *
     * On success, the @ref DC_MSG "view type of the message" may change
     * or the message may be replaced completely by one or more messages with other message IDs.
     * That may happen e.g. in cases where the message was encrypted
     * and the type could not be determined without fully downloading.
     * Downloaded content can be accessed as usual after download.
     *
     * To reflect these changes a @ref DC_EVENT_MSGS_CHANGED event will be emitted.
     */
    downloadFullMessage(accountId: T.U32, messageId: T.U32): Promise<null>;
    /**
     * Search messages containing the given query string.
     * Searching can be done globally (chat_id=None) or in a specified chat only (chat_id set).
     *
     * Global search results are typically displayed using dc_msg_get_summary(), chat
     * search results may just highlight the corresponding messages and present a
     * prev/next button.
     *
     * For the global search, the result is limited to 1000 messages,
     * this allows an incremental search done fast.
     * So, when getting exactly 1000 messages, the result actually may be truncated;
     * the UIs may display sth. like "1000+ messages found" in this case.
     * The chat search (if chat_id is set) is not limited.
     */
    searchMessages(accountId: T.U32, query: string, chatId: (T.U32 | null)): Promise<(T.U32)[]>;
    messageIdsToSearchResults(accountId: T.U32, messageIds: (T.U32)[]): Promise<Record<T.U32, T.MessageSearchResult>>;
    /**
     * Get a single contact options by ID.
     */
    getContact(accountId: T.U32, contactId: T.U32): Promise<T.Contact>;
    /**
     * Add a single contact as a result of an explicit user action.
     *
     * Returns contact id of the created or existing contact
     */
    createContact(accountId: T.U32, email: string, name: (string | null)): Promise<T.U32>;
    /**
     * Returns contact id of the created or existing DM chat with that contact
     */
    createChatByContactId(accountId: T.U32, contactId: T.U32): Promise<T.U32>;
    blockContact(accountId: T.U32, contactId: T.U32): Promise<null>;
    unblockContact(accountId: T.U32, contactId: T.U32): Promise<null>;
    getBlockedContacts(accountId: T.U32): Promise<(T.Contact)[]>;
    getContactIds(accountId: T.U32, listFlags: T.U32, query: (string | null)): Promise<(T.U32)[]>;
    /**
     * Get a list of contacts.
     * (formerly called getContacts2 in desktop)
     */
    getContacts(accountId: T.U32, listFlags: T.U32, query: (string | null)): Promise<(T.Contact)[]>;
    getContactsByIds(accountId: T.U32, ids: (T.U32)[]): Promise<Record<T.U32, T.Contact>>;
    deleteContact(accountId: T.U32, contactId: T.U32): Promise<null>;
    changeContactName(accountId: T.U32, contactId: T.U32, name: string): Promise<null>;
    /**
     * Get encryption info for a contact.
     * Get a multi-line encryption info, containing your fingerprint and the
     * fingerprint of the contact, used e.g. to compare the fingerprints for a simple out-of-band verification.
     */
    getContactEncryptionInfo(accountId: T.U32, contactId: T.U32): Promise<string>;
    /**
     * Check if an e-mail address belongs to a known and unblocked contact.
     * To get a list of all known and unblocked contacts, use contacts_get_contacts().
     *
     * To validate an e-mail address independently of the contact database
     * use check_email_validity().
     */
    lookupContactIdByAddr(accountId: T.U32, addr: string): Promise<(T.U32 | null)>;
    /**
     * Returns the [`ChatId`] for the 1:1 chat with `contact_id` if it exists.
     *
     * If it does not exist, `None` is returned.
     */
    getChatIdByContactId(accountId: T.U32, contactId: T.U32): Promise<(T.U32 | null)>;
    /**
     * Returns all message IDs of the given types in a chat.
     * Typically used to show a gallery.
     *
     * The list is already sorted and starts with the oldest message.
     * Clients should not try to re-sort the list as this would be an expensive action
     * and would result in inconsistencies between clients.
     *
     * Setting `chat_id` to `None` (`null` in typescript) means get messages with media
     * from any chat of the currently used account.
     */
    getChatMedia(accountId: T.U32, chatId: (T.U32 | null), messageType: T.Viewtype, orMessageType2: (T.Viewtype | null), orMessageType3: (T.Viewtype | null)): Promise<(T.U32)[]>;
    /**
     * Search next/previous message based on a given message and a list of types.
     * Typically used to implement the "next" and "previous" buttons
     * in a gallery or in a media player.
     *
     * one combined call for getting chat::get_next_media for both directions
     * the manual chat::get_next_media in only one direction is not exposed by the jsonrpc yet
     *
     * Deprecated 2023-10-03, use `get_chat_media` method
     * and navigate the returned array instead.
     */
    getNeighboringChatMedia(accountId: T.U32, msgId: T.U32, messageType: T.Viewtype, orMessageType2: (T.Viewtype | null), orMessageType3: (T.Viewtype | null)): Promise<[(T.U32 | null), (T.U32 | null)]>;
    exportBackup(accountId: T.U32, destination: string, passphrase: (string | null)): Promise<null>;
    importBackup(accountId: T.U32, path: string, passphrase: (string | null)): Promise<null>;
    /**
     * Offers a backup for remote devices to retrieve.
     *
     * Can be cancelled by stopping the ongoing process.  Success or failure can be tracked
     * via the `ImexProgress` event which should either reach `1000` for success or `0` for
     * failure.
     *
     * This **stops IO** while it is running.
     *
     * Returns once a remote device has retrieved the backup, or is cancelled.
     */
    provideBackup(accountId: T.U32): Promise<null>;
    /**
     * Returns the text of the QR code for the running [`CommandApi::provide_backup`].
     *
     * This QR code text can be used in [`CommandApi::get_backup`] on a second device to
     * retrieve the backup and setup this second device.
     *
     * This call will fail if there is currently no concurrent call to
     * [`CommandApi::provide_backup`].  This call may block if the QR code is not yet
     * ready.
     */
    getBackupQr(accountId: T.U32): Promise<string>;
    /**
     * Returns the rendered QR code for the running [`CommandApi::provide_backup`].
     *
     * This QR code can be used in [`CommandApi::get_backup`] on a second device to
     * retrieve the backup and setup this second device.
     *
     * This call will fail if there is currently no concurrent call to
     * [`CommandApi::provide_backup`].  This call may block if the QR code is not yet
     * ready.
     *
     * Returns the QR code rendered as an SVG image.
     */
    getBackupQrSvg(accountId: T.U32): Promise<string>;
    /**
     * Gets a backup from a remote provider.
     *
     * This retrieves the backup from a remote device over the network and imports it into
     * the current device.
     *
     * Can be cancelled by stopping the ongoing process.
     */
    getBackup(accountId: T.U32, qrText: string): Promise<null>;
    /**
     * Indicate that the network likely has come back.
     * or just that the network conditions might have changed
     */
    maybeNetwork(): Promise<null>;
    /**
     * Get the current connectivity, i.e. whether the device is connected to the IMAP server.
     * One of:
     * - DC_CONNECTIVITY_NOT_CONNECTED (1000-1999): Show e.g. the string "Not connected" or a red dot
     * - DC_CONNECTIVITY_CONNECTING (2000-2999): Show e.g. the string "Connecting…" or a yellow dot
     * - DC_CONNECTIVITY_WORKING (3000-3999): Show e.g. the string "Getting new messages" or a spinning wheel
     * - DC_CONNECTIVITY_CONNECTED (>=4000): Show e.g. the string "Connected" or a green dot
     *
     * We don't use exact values but ranges here so that we can split up
     * states into multiple states in the future.
     *
     * Meant as a rough overview that can be shown
     * e.g. in the title of the main screen.
     *
     * If the connectivity changes, a #DC_EVENT_CONNECTIVITY_CHANGED will be emitted.
     */
    getConnectivity(accountId: T.U32): Promise<T.U32>;
    /**
     * Get an overview of the current connectivity, and possibly more statistics.
     * Meant to give the user more insight about the current status than
     * the basic connectivity info returned by get_connectivity(); show this
     * e.g., if the user taps on said basic connectivity info.
     *
     * If this page changes, a #DC_EVENT_CONNECTIVITY_CHANGED will be emitted.
     *
     * This comes as an HTML from the core so that we can easily improve it
     * and the improvement instantly reaches all UIs.
     */
    getConnectivityHtml(accountId: T.U32): Promise<string>;
    getLocations(accountId: T.U32, chatId: (T.U32 | null), contactId: (T.U32 | null), timestampBegin: T.I64, timestampEnd: T.I64): Promise<(T.Location)[]>;
    sendWebxdcStatusUpdate(accountId: T.U32, instanceMsgId: T.U32, updateStr: string, description: string): Promise<null>;
    getWebxdcStatusUpdates(accountId: T.U32, instanceMsgId: T.U32, lastKnownSerial: T.U32): Promise<string>;
    /**
     * Get info from a webxdc message
     */
    getWebxdcInfo(accountId: T.U32, instanceMsgId: T.U32): Promise<T.WebxdcMessageInfo>;
    /**
     * Get blob encoded as base64 from a webxdc message
     *
     * path is the path of the file within webxdc archive
     */
    getWebxdcBlob(accountId: T.U32, instanceMsgId: T.U32, path: string): Promise<string>;
    /**
     * Makes an HTTP GET request and returns a response.
     *
     * `url` is the HTTP or HTTPS URL.
     */
    getHttpResponse(accountId: T.U32, url: string): Promise<T.HttpResponse>;
    /**
     * Forward messages to another chat.
     *
     * All types of messages can be forwarded,
     * however, they will be flagged as such (dc_msg_is_forwarded() is set).
     *
     * Original sender, info-state and webxdc updates are not forwarded on purpose.
     */
    forwardMessages(accountId: T.U32, messageIds: (T.U32)[], chatId: T.U32): Promise<null>;
    /**
     * Resend messages and make information available for newly added chat members.
     * Resending sends out the original message, however, recipients and webxdc-status may differ.
     * Clients that already have the original message can still ignore the resent message as
     * they have tracked the state by dedicated updates.
     *
     * Some messages cannot be resent, eg. info-messages, drafts, already pending messages or messages that are not sent by SELF.
     *
     * message_ids all message IDs that should be resend. All messages must belong to the same chat.
     */
    resendMessages(accountId: T.U32, messageIds: (T.U32)[]): Promise<null>;
    sendSticker(accountId: T.U32, chatId: T.U32, stickerPath: string): Promise<T.U32>;
    /**
     * Send a reaction to message.
     *
     * Reaction is a string of emojis separated by spaces. Reaction to a
     * single message can be sent multiple times. The last reaction
     * received overrides all previously received reactions. It is
     * possible to remove all reactions by sending an empty string.
     */
    sendReaction(accountId: T.U32, messageId: T.U32, reaction: (string)[]): Promise<T.U32>;
    /**
     * Returns reactions to the message.
     */
    getMessageReactions(accountId: T.U32, messageId: T.U32): Promise<(T.Reactions | null)>;
    sendMsg(accountId: T.U32, chatId: T.U32, data: T.MessageData): Promise<T.U32>;
    /**
     * Checks if messages can be sent to a given chat.
     */
    canSend(accountId: T.U32, chatId: T.U32): Promise<boolean>;
    removeDraft(accountId: T.U32, chatId: T.U32): Promise<null>;
    /**
     *  Get draft for a chat, if any.
     */
    getDraft(accountId: T.U32, chatId: T.U32): Promise<(T.Message | null)>;
    sendVideochatInvitation(accountId: T.U32, chatId: T.U32): Promise<T.U32>;
    miscGetStickerFolder(accountId: T.U32): Promise<string>;
    /**
     * Saves a sticker to a collection/folder in the account's sticker folder.
     */
    miscSaveSticker(accountId: T.U32, msgId: T.U32, collection: string): Promise<null>;
    /**
     * for desktop, get stickers from stickers folder,
     * grouped by the collection/folder they are in.
     */
    miscGetStickers(accountId: T.U32): Promise<Record<string, (string)[]>>;
    /**
     * Returns the messageid of the sent message
     */
    miscSendTextMessage(accountId: T.U32, chatId: T.U32, text: string): Promise<T.U32>;
    miscSendMsg(accountId: T.U32, chatId: T.U32, text: (string | null), file: (string | null), location: ([T.F64, T.F64] | null), quotedMessageId: (T.U32 | null)): Promise<[T.U32, T.Message]>;
    miscSetDraft(accountId: T.U32, chatId: T.U32, text: (string | null), file: (string | null), quotedMessageId: (T.U32 | null), viewType: (T.Viewtype | null)): Promise<null>;
    miscSendDraft(accountId: T.U32, chatId: T.U32): Promise<T.U32>;
}
export {};
